import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import easytrader

user = easytrader.use('ths')
user.connect(r'D:\Program Files\ths\xiadan.exe')


## 自动一键打新
def auto_ipo_buy():
    user.auto_ipo()


if __name__ == '__main__':
    auto_ipo_buy()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.ths.ths_stock_api as ths_stock_api

import datetime
import time
import mns_common.api.msg.push_msg_api as push_msg_api
from loguru import logger
import mns_scheduler.concept.ths.common.ths_concept_sync_common_api as ths_concept_sync_common_api

from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')


# 获取web端 新增概念详情
def get_concept_detail_info_web(concept_code):
    new_concept_symbol_list = ths_stock_api.ths_stock_concept(concept_code)
    if new_concept_symbol_list is None or new_concept_symbol_list.shape[0] == 0:
        return None
    new_concept_symbol_list = new_concept_symbol_list[ths_concept_sync_common_api.order_fields]
    new_concept_symbol_list['_id'] = str(concept_code) + '-' + new_concept_symbol_list['symbol']
    return new_concept_symbol_list


# web端获取新概念消息推送
def push_msg_to_we_chat_web(concept_code, concept_name):
    url = 'http://q.10jqka.com.cn/thshy/detail/code/' + str(concept_code)
    msg = "概念代码:" + str(concept_code) + "," + "概念名称:" + concept_name + "," + "url:   " + url
    title = "新增同花顺概念:" + str(concept_code) + "-" + concept_name
    push_msg_api.push_msg_to_wechat(title, msg)


#     # 同步同花顺新增概念指数通过web端接口爬取
def sync_new_concept_data_by_web():
    concept_code = ths_concept_sync_common_api.get_max_concept_code()
    concept_code = concept_code + 1

    while concept_code < ths_concept_sync_common_api.max_concept_code:
        try:
            now_date = datetime.datetime.now()
            str_day = now_date.strftime('%Y-%m-%d')
            str_now_time = now_date.strftime('%Y-%m-%d %H:%M:%S')
            new_concept_symbol_df = get_concept_detail_info_web(concept_code)
            if new_concept_symbol_df is None or new_concept_symbol_df.shape[0] == 0:
                concept_code = concept_code + 1
                time.sleep(1)
                continue
            time.sleep(2)
            concept_name = ths_stock_api.get_concept_name(concept_code)
            concept_name = concept_name.replace(' ',                                                '')
            concept_name = concept_name.replace('（', '(')
            concept_name = concept_name.replace('）', ')')

            url = 'http://q.10jqka.com.cn/thshy/detail/code/' + str(concept_code)
            # 推送新概念信息到微信
            ths_concept_sync_common_api.push_msg_to_we_chat_web(concept_code, concept_name, url)
            # 保存新概念信息到概念列表
            ths_concept_sync_common_api.save_ths_concept_list(concept_code, concept_name, str_day, str_now_time)
            # 保存新概念详细信息到数据库
            new_concept_symbol_df.loc[:, 'way'] = 'index_sync'
            ths_concept_sync_common_api.save_ths_concept_detail(new_concept_symbol_df, concept_name, str_day,
                                                                str_now_time, concept_code)

            concept_code = concept_code + 1
        except BaseException as e:
            logger.error("同步新概念异常:{},concept_code:{}", e, concept_code)
            concept_code = concept_code + 1


if __name__ == '__main__':
    # code = 886025
    # name = ths_stock_api.get_concept_name(code)
    # push_msg_to_we_chat_web(code, name)
    # get_concept_detail_info_web(886026)
    # get_concept_detail_info_web(886035)
    sync_new_concept_data_by_web()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.constant.ths_concept_no_choose_constant as no_choose_constant
from mns_common.db.MongodbUtil import MongodbUtil
import pandas as pd
import mns_common.api.ths.ths_stock_api as ths_stock_api
import time

mongodb_util = MongodbUtil('27017')


def choose_effective_ths_concept():
    exclude_ths_concept_df = no_choose_constant.get_simple_exclude_ths_concept()
    ths_concept_list_df = mongodb_util.find_all_data('ths_concept_list')

    ths_concept_list_df['symbol'] = ths_concept_list_df['symbol'].astype(str)
    # 排除3开头的概念
    ths_concept_list_df = ths_concept_list_df.loc[ths_concept_list_df['symbol'].str.startswith('8')]

    ths_concept_list_df['symbol'] = ths_concept_list_df['symbol'].astype(float)

    effective_ths_concept_df = ths_concept_list_df.loc[~(
        ths_concept_list_df['symbol'].isin(list(exclude_ths_concept_df['symbol'])))]

    mongodb_util.remove_data({'_id': {"$exists": True}}, 'ths_concept_list_effective')
    effective_ths_concept_df = effective_ths_concept_df.sort_values(by=['str_day'], ascending=False)
    mongodb_util.insert_mongo(effective_ths_concept_df, 'ths_concept_list_effective')

    # 保存无效概念
    exclude_ths_concept_df = ths_concept_list_df.loc[(
        ths_concept_list_df['symbol'].isin(list(exclude_ths_concept_df['symbol'])))]

    mongodb_util.remove_data({'_id': {"$exists": True}}, 'ths_concept_list_exclude')
    mongodb_util.insert_mongo(exclude_ths_concept_df, 'ths_concept_list_exclude')


# 统计概念数量
def update_concept_num():
    ths_concept_list = mongodb_util.find_all_data('ths_concept_list')
    for ths_concept_one in ths_concept_list.itertuples():
        query = {'concept_code': ths_concept_one.symbol}
        concept_count = (mongodb_util
                         .count(query, 'ths_stock_concept_detail'))
        ths_concept_list_one_df = ths_concept_list.loc[ths_concept_list['symbol'] == ths_concept_one.symbol]
        ths_concept_list_one_df['concept_count'] = concept_count
        mongodb_util.save_mongo(ths_concept_list_one_df, 'ths_concept_list')


def update_null_name():
    query = {"_id": {'$gte': 886025}}
    ths_concept_list = mongodb_util.find_query_data('ths_concept_list', query)
    ths_concept_list = ths_concept_list.sort_values(by=['_id'], ascending=False)

    for concept_one in ths_concept_list.itertuples():
        concept_code = concept_one.symbol
        name = concept_one.name
        exist_url = concept_one.url

        if name == '':
            concept_name = ths_stock_api.get_concept_name(concept_code)
            query_concept = {"symbol": concept_code}
            new_values = {'$set': {"name": concept_name}}
            mongodb_util.update_one_query(query_concept, new_values, 'ths_concept_list')

            new_values_detail = {'$set': {"concept_name": concept_name}}

            query_concept_detail = {"concept_code": concept_code}

            mongodb_util.update_many(query_concept_detail, new_values_detail, 'ths_stock_concept_detail')
            time.sleep(10)

        if exist_url == '' or pd.isna(exist_url):
            url = 'http://q.10jqka.com.cn/thshy/detail/code/' + str(concept_code)
            str_now_time = concept_one.str_day + " " + "00:00:00"
            query_concept = {"symbol": concept_code}
            new_values = {'$set': {"url": url, "str_now_time": str_now_time}}
            mongodb_util.update_one_query(query_concept, new_values, 'ths_concept_list')


if __name__ == '__main__':
    update_null_name()
    choose_effective_ths_concept()
    update_concept_num()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.msg.push_msg_api as push_msg_api
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
from loguru import logger
import mns_common.utils.ip_util as ip_util


def db_status_check():
    try:
        query = {'symbol': '000001'}
        mongodb_util.find_query_data('company_info', query)
    except BaseException as e:
        ip = ip_util.get_host_ip()
        push_msg_api.push_msg_to_wechat("数据库挂了", "地址:" + ip + "-" + "数据库挂了")
        logger.error("出现异常:{}", e)
        return



import sys
import os

import mns_common.api.kpl.selection.kpl_selection_plate_api as selection_plate_api
from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger
import mns_common.api.kpl.constant.kpl_constant as kpl_constant
import mns_common.utils.data_frame_util as data_frame_util
import mns_scheduler.kpl.selection.index.sync_best_choose_index as sync_best_choose_first_index
import mns_scheduler.kpl.selection.symbol.sync_best_choose_symbol as sync_best_choose_symbol
import threading

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

mongodb_util = MongodbUtil('27017')

# 分页大小
MAX_PAGE_NUMBER = 10


# 同步开票啦精选概念股票组成
def sync_best_choose_symbol_detail(first_index_df, page_number):
    for stock_one in first_index_df.itertuples():
        try:
            # 保存一级精选指数股票组成
            sync_best_choose_symbol.save_one_plate_detail_data(stock_one.plate_code,
                                                               stock_one.plate_name,
                                                               kpl_constant.FIRST_INDEX,
                                                               stock_one.plate_code,
                                                               stock_one.plate_name)

            kpl_best_choose_sub_index_detail = selection_plate_api.best_choose_sub_index(stock_one.plate_code)

            if data_frame_util.is_not_empty(kpl_best_choose_sub_index_detail):
                for sub_one in kpl_best_choose_sub_index_detail.itertuples():
                    try:
                        sync_best_choose_symbol.save_one_plate_detail_data(sub_one.plate_code,
                                                                           sub_one.plate_name,
                                                                           kpl_constant.SUB_INDEX,
                                                                           stock_one.plate_code,
                                                                           stock_one.plate_name)
                    except BaseException as e:
                        logger.error("同步开盘啦精选板块二级指数详情异常:{},{}", sub_one.plate_code, e)

        except BaseException as e:
            logger.error("同步开盘啦精选板块二级指数异常:{},{}", stock_one.plate_code, e)


def multi_thread_sync_kpl_best_choose_detail():
    first_index_df = sync_best_choose_first_index.choose_field_choose_first_index()
    count = first_index_df.shape[0]
    page_number = round(count / MAX_PAGE_NUMBER, 0) + 1
    page_number = int(page_number)
    threads = []
    # 创建多个线程来获取数据
    for page in range(page_number):  # 0到100页
        end_count = (page + 1) * MAX_PAGE_NUMBER
        begin_count = page * MAX_PAGE_NUMBER
        page_df = first_index_df.iloc[begin_count:end_count]
        thread = threading.Thread(target=sync_best_choose_symbol_detail, args=(page_df, page_number))
        threads.append(thread)
        thread.start()

    # 等待所有线程完成
    for thread in threads:
        thread.join()


# 同步所有精选指数信息
def sync_all_plate_info():
    # 同步第一和第二级别精选指数
    # 更新一级和二级之间的关联关系
    # 找出新增精选指数
    sync_best_choose_first_index.sync_best_choose_index()
    logger.info("同步开票啦精选概念指数完成")
    # 同步精选概念股票组成
    multi_thread_sync_kpl_best_choose_detail()
    logger.info("同步开票啦精选概念股票组成完成")


if __name__ == '__main__':
    # 同步第一和第二级别精选指数
    sync_all_plate_info()
